#ifndef TREND_H
#define TREND_H

/*
  This file is part of "WeightJinni" - A program to control your weight.
  Copyright (C) 2008  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Model/Number.h>

#include <Lum/OS/DrawInfo.h>

#include <Lum/Object.h>

class Trend : public Lum::Control
{
public:
  enum State {
    none = 0,
    up = 1,
    down = 2
  };

private:
  Lum::OS::ColorRef  noneColor;
  Lum::OS::ColorRef  upColor;
  Lum::OS::ColorRef  downColor;
  Lum::Model::IntRef model;

public:
  Trend();
  ~Trend();

  bool SetModel(Lum::Base::Model* model);

  void CalcSize();

  void Draw(Lum::OS::DrawInfo* draw,
            int x, int y, size_t w, size_t h);

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
};

#endif
